@@ -1,6 +1,6 @@
 /**
  *	This file is part of devilspie2
- *	Copyright (C) 2011-2013 Andreas Rönnquist
+ *	Copyright (C) 2011-2014 Andreas Rönnquist
  *
  *	devilspie2 is free software: you can redistribute it and/or
  *	modify it under the terms of the GNU General Public License as published
@@ -84,6 +84,7 @@ register_cfunctions(lua_State *lua)
 	lua_register(lua, "set_window_position", c_set_window_position);
 	lua_register(lua, "set_window_position2", c_set_window_position2);
 	lua_register(lua, "set_window_size", c_set_window_size);
+	lua_register(lua, "set_window_strut", c_set_window_strut);
 
 	lua_register(lua, "set_window_geometry", c_set_window_geometry);
 	lua_register(lua, "set_window_geometry2", c_set_window_geometry2);
@@ -160,6 +161,9 @@ register_cfunctions(lua_State *lua)
 	lua_register(lua, "set_window_type", c_set_window_type);
 
 	lua_register(lua, "get_screen_geometry", c_get_screen_geometry);
+	
+	lua_register(lua, "get_window_fullscreen", c_get_window_fullscreen);
+	lua_register(lua, "get_fullscreen", c_get_window_fullscreen);
 
 #ifdef HAVE_GTK3
 	// wnck_window_get_class_instance_name is only availible on wnck 3 and later
@@ -168,6 +172,9 @@ register_cfunctions(lua_State *lua)
 
 	lua_register(lua, "focus", c_focus);
 	lua_register(lua, "focus_window", c_focus);
+	
+	lua_register(lua, "xy", c_xy);
+	lua_register(lua, "xywh", c_xywh);
 
 }
 
